@@ -17,15 +17,12 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
-/* #if !defined(LIBXFCE4PANEL_INSIDE_LIBXFCE4PANEL_H) && !defined(LIBXFCE4PANEL_COMPILATION)
-#error "Only <libxfce4panel/libxfce4panel.h> can be included directly, this file may disappear or change contents"
-#endif */
+
 
 #ifndef __XFCE_PANEL_CONVENIENCE_H__
 #define __XFCE_PANEL_CONVENIENCE_H__
 
 #include <gtk/gtk.h>
-#include <libxfce4panel/xfce-panel-macros-46.h>
 
 G_BEGIN_DECLS
 
