@@ -49,6 +49,7 @@ static void      panel_dbus_service_plugin_event_result        (XfcePanelPluginP
 static gboolean  panel_dbus_service_display_preferences_dialog (XfcePanelExportedService *skeleton,
                                                                 GDBusMethodInvocation    *invocation,
                                                                 guint                     active,
+                                                                guint                     socket_id,
                                                                 PanelDBusService         *service);
 static gboolean  panel_dbus_service_display_items_dialog       (XfcePanelExportedService *skeleton,
                                                                 GDBusMethodInvocation    *invocation,
@@ -196,12 +197,13 @@ static gboolean
 panel_dbus_service_display_preferences_dialog (XfcePanelExportedService *skeleton,
                                                GDBusMethodInvocation    *invocation,
                                                guint                     active,
+                                               guint                     socket_id,
                                                PanelDBusService         *service)
 {
   panel_return_val_if_fail (PANEL_IS_DBUS_SERVICE (service), FALSE);
 
-  /* show the items dialog */
-  panel_item_dialog_show_from_id (active);
+  /* show the preferences dialog */
+  panel_preferences_dialog_show_from_id (active, socket_id);
 
   xfce_panel_exported_service_complete_display_preferences_dialog(skeleton, invocation);
 
