@@ -98,6 +98,8 @@ struct _PanelItembar
   /* some properties we clone from the panel window */
   XfcePanelPluginMode  mode;
   gint                 size;
+  gboolean             dark_mode;
+  gint                 icon_size;
   gint                 nrows;
 
   /* dnd support */
@@ -127,6 +129,8 @@ enum
   PROP_0,
   PROP_MODE,
   PROP_SIZE,
+  PROP_ICON_SIZE,
+  PROP_DARK_MODE,
   PROP_NROWS
 };
 
@@ -203,6 +207,20 @@ panel_itembar_class_init (PanelItembarClass *klass)
                                                       16, 128, 30,
                                                       G_PARAM_WRITABLE | G_PARAM_STATIC_STRINGS));
 
+  g_object_class_install_property (gobject_class,
+                                   PROP_ICON_SIZE,
+                                   g_param_spec_uint ("icon-size",
+                                                      NULL, NULL,
+                                                      0, 256, 0,
+                                                      G_PARAM_WRITABLE | G_PARAM_STATIC_STRINGS));
+
+  g_object_class_install_property (gobject_class,
+                                   PROP_DARK_MODE,
+                                   g_param_spec_boolean ("dark-mode",
+                                                         NULL, NULL,
+                                                         FALSE,
+                                                         G_PARAM_WRITABLE | G_PARAM_STATIC_STRINGS));
+
   g_object_class_install_property (gobject_class,
                                    PROP_NROWS,
                                    g_param_spec_uint ("nrows",
@@ -240,6 +258,8 @@ panel_itembar_init (PanelItembar *itembar)
   itembar->children = NULL;
   itembar->mode = XFCE_PANEL_PLUGIN_MODE_HORIZONTAL;
   itembar->size = 30;
+  itembar->icon_size = 0;
+  itembar->dark_mode = FALSE;
   itembar->nrows = 1;
   itembar->highlight_index = -1;
   itembar->highlight_length = -1;
@@ -269,6 +289,14 @@ panel_itembar_set_property (GObject      *object,
       itembar->size = g_value_get_uint (value);
       break;
 
+    case PROP_ICON_SIZE:
+      itembar->icon_size = g_value_get_uint (value);
+      break;
+
+    case PROP_DARK_MODE:
+      itembar->dark_mode = g_value_get_boolean (value);
+      break;
+
     case PROP_NROWS:
       itembar->nrows = g_value_get_uint (value);
       break;
