@@ -556,11 +556,7 @@ launcher_plugin_item_duplicate (GFile   *src_file,
     goto err1;
 
   result = g_file_replace_contents (dst_file, contents, length, NULL, FALSE,
-#if GLIB_CHECK_VERSION (2, 20, 0)
                                     G_FILE_CREATE_REPLACE_DESTINATION,
-#else
-                                    G_FILE_CREATE_NONE,
-#endif
                                     NULL, NULL, error);
 
 err1:
@@ -2502,7 +2498,7 @@ launcher_plugin_item_exec_on_screen (GarconMenuItem *item,
                             garcon_menu_item_get_path (item),
                             argv, NULL, G_SPAWN_SEARCH_PATH,
                             garcon_menu_item_supports_startup_notification (item),
-                            event_time, icon, FALSE, &error);
+                            event_time, icon, TRUE, &error);
 
       g_strfreev (argv);
     }
